/*
 * voicechat - Voice chat via TCP/IP
 * Version 0.40 beta (October 29th, 1995)
 *
 * Copyright 1995 Riku Saikkonen (rjs@spider.compart.fi)
 *
 * This program is free software; you can redistribute and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program (as the file COPYING); if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * The author, Riku Saikkonen, can be contacted via the following means:
 * E-mail (preferred): rjs@spider.compart.fi
 * Paper mail: Riku Saikkonen
 *             Alakartanontie 4 B 63
 *             SF-02360  ESPOO
 *             Finland
 */

#ifndef VOICECHAT_H

#include "config.h"

/* Banners */

#define SHORTBANNER "voicechat 0.40 beta"

#define BANNER "voicechat - Voice chat through TCP/IP\n" \
  "Copyright 1995 Riku Saikkonen (rjs@spider.compart.fi)\n" \
  "Voicechat is free software, distributed under the terms of the GNU " \
    "General\n" \
  "Public License version 2, and comes with ABSOLUTELY NO WARRANTY; for " \
    "details,\n" \
  "see the file README distributed with the program.\n"

/* Audio packet sizes (GSM) */
#define AUDIOSZ_C 33 /* Compressed */
#define AUDIOSZ_U 160 /* Uncompressed */

/* External variables and function prototypes */

/* bufin.c */

extern int netinsize;

void handle_soundin(void);
void handle_netin(void);

/* bufout.c */

extern int nobufpos,sobufpos,flush_soundout,netoutsize;

void netout(char *buf, int len);
void handle_netout(void);
void soundout(char *buf, int len);
void handle_soundout(void);

/* display.c */

extern int display_initialised;
extern int orecording,update_status,testreply;

void disp_init(void);
void disp_tick(void);
void disp_redraw(void);
void disp_deinit(void);
void disp_writeown(char ch);
void disp_writeother(char ch);
void disp_writemsg(char *msg);

/* error.c */

void message(char *msg);
void warning(char *msg);
void fatal(char *msg);
void fatals(char *msg);

/* keyboard.c */

void handle_kbd(void);

/* net.c */

extern int netfd;

void open_net_connect(char *hostname, int port);
void open_net_listen(int port);
void close_net(void);

/* sound.c */

extern int recording,soundfd,soundrfd,silencelimit;

void sound_init(void);
void sound_deinit(void);
void record_on(void);
void record_off(void);
void play_sound(void);
void send_sound(char *sp);
void receive_sound(char *sp);
void receive_sound_silence(void);

/* voicechat.c */

extern int quitting;

#endif /* VOICECHAT_H */
